@@ -11,6 +11,8 @@
     // Path for SquirrelMail required files.
     define('SM_PATH','../../');
 
+    // include compatibility plugin
+    include_once(SM_PATH . 'plugins/compatibility/functions.php');
     if (file_exists(SM_PATH . 'include/validate.php')) {
         include_once(SM_PATH . 'include/validate.php');
     } else {
@@ -32,11 +34,10 @@
     // grab colours from pref and text string from GET
     $background_color_get = substr($color[3],1);
     $text_color_get       = substr($color[6],1);
-    sqgetGlobalVar('button_text', $button_text);
-    sqgetGlobalVar('button_link', $button_link);
+    $string               = $_GET['button_text'];
 
     header("Content-Type: image/png");
-    header("Content-Disposition: filename=$button_link.png"); 
+    header("Content-Disposition: filename=$string.png"); 
 
     // send headers to browser - allow caching
     if (($image_buttons_cache == 'yes') || ($image_buttons_cache == '')) {
@@ -56,7 +57,7 @@
         $image_buttons_size = 4;
     }
 
-    $chars = strlen($button_text);
+    $chars = strlen($string);
     $strwidth = ImageFontWidth($image_buttons_size) * $chars;
     $strheight = ImageFontHeight($image_buttons_size);
     $img_width = $strwidth + 8;
@@ -96,7 +97,7 @@
 
     // write the text in the button
     ImageString($id, $image_buttons_size, ($img_center_x - ($strwidth / 2) + 1),
-                ($img_center_y - ($strheight / 2) - 1), $button_text, $text_color);
+                ($img_center_y - ($strheight / 2) - 1), $string, $text_color);
 
     // send out the image
     ImagePng($id);
